@@ -9,6 +9,7 @@ Description:
 from math import fsum
 
 from confopy.analysis import Metric, Analyzer, SpellChecker, NO_WORDS
+from pattern.de import lemma
 
 # General German metrics
 
@@ -20,7 +21,7 @@ class WordLengthMetric(Metric):
 
     def evaluate(self, node):
         A = Analyzer.instance()
-        corp = A.get(corpus=u"TIGER")
+        #corp = A.get(corpus=u"TIGER")
         words = node.words()
         word_count = len(words)
         word_len = reduce(lambda w, v: w + v, [len(w) for w in words], 0)
@@ -57,8 +58,18 @@ class LexiconMetric(Metric):
 
     def evaluate(self, node):
         words = node.words()
-        if len(words) > 0:
-            unique_words = set(words)
+        A = Analyzer.instance()
+        corp = A.get(corpus=u"TIGER")
+        tagger = corp.tagger(True)
+        tagged_words = tagger.tag(words)
+        unique_words = set()
+        if len(tagged_words) > 0:
+            for w in tagged_words:
+                if w[1] and w[1].startswith(u"V"):
+                    lemm = lemma(w[0])
+                    unique_words.add(lemm)
+                else:
+                    unique_words.add(w[0])
             return float(len(unique_words)) / len(words)
         return 0.0
 Analyzer.register(LexiconMetric())
@@ -89,7 +100,7 @@ class PersonalStyleMetric(Metric):
     PERSONAL = [u"ich", u"wir", u"sie"]
 
     def __init__(self):
-        super(PersonalStyleMetric, self).__init__(u"personalstyle", u"de", u"Persönlicher Schreibstil")
+        super(PersonalStyleMetric, self).__init__(u"personalstyle", u"de", u"Persönlicher Schreibstil", u"Vorkommen von 'ich', 'wir', 'sie' relativ zur Satzanzahl.")
 
     def evaluate(self, node):
         words = node.words()
@@ -108,11 +119,9 @@ Analyzer.register(PersonalStyleMetric())
 
 #### durchschnittliche Anzahl von Passiv-/"Man"-Konstrukten pro Satz
 class ImpersonalStyleMetric(Metric):
-
-    IMPERSONAL = [u"man"]
-
-    def __init__(self):
-        super(ImpersonalStyleMetric, self).__init__(u"impersonalstyle", u"de", u"Unpersönlicher Schreibstil")
+    def __init__(self, ID=u"impersonalstyle", lang=u"de", description=u"Unpersönlicher Schreibstil"):
+        super(ImpersonalStyleMetric, self).__init__(ID, lang, description)
+        self.IMPERSONAL = [u"man"]
 
     def evaluate(self, node):
         words = node.words()
@@ -122,13 +131,21 @@ class ImpersonalStyleMetric(Metric):
         count = 0
         for w in words:
             low = w.lower()
-            if low in ImpersonalStyleMetric.IMPERSONAL:
+            if low in self.IMPERSONAL:
                 count += 1
         if sents_count > 0:
             return float(count) / sents_count
         return 0.0
 Analyzer.register(ImpersonalStyleMetric())
 
+### Passivkonstrukte mit "werden"
+class PassiveConstructsMetric(ImpersonalStyleMetric):
+    """docstring for PassiveConstructsMetric"""
+    def __init__(self):
+        super(PassiveConstructsMetric, self).__init__(u"passiveconstructs", u"de", "Passivkonstrukte mit \"werden\"")
+        self.IMPERSONAL = [u"werden"]
+Analyzer.register(PassiveConstructsMetric())
+
 ### Zeitform (Präsens), Anzahl der Verben in Präs. durch Gesamtanzahl an Verben
 class SimplePresentMetric(Metric):
     def __init__(self):
@@ -142,12 +159,12 @@ class SimplePresentMetric(Metric):
         pres_verbs = 0
         total_verbs = 0
         for w in tagged_words:
-            if w[1] and u"V" in w[1]:
-                if w[1].startswith(u"VVFIN"): # beinhaltet noch vergangenheit!
+            if w[1] and w[1].startswith(u"V"):
+                if w[1].startswith(u"VVFIN") or\
+                   w[1].startswith(u"VAFIN") or\
+                   w[1].startswith(u"VVINF") or\
+                   w[1].startswith(u"VVIZU"): # beinhaltet noch vergangenheit!
                     pres_verbs += 1
-                else:
-                    pass
-                    #print w
                 total_verbs += 1
                 #print w
         if total_verbs > 0:
@@ -177,7 +194,33 @@ class AdverbModifierMetric(Metric):
         return 0.0
 Analyzer.register(AdverbModifierMetric())
 
+
 ### Vermeidung toter Verben (Gehören, liegen, beinhalten)
+class DeadVerbsMetric(Metric):
+    """docstring for DeadVerbsMetric"""
+    def __init__(self, ID=u"deadverbs", lang=u"de", description=u"Anzahl toter Verben"):
+        super(DeadVerbsMetric, self).__init__(ID, lang, description)
+        # weitere tote Verben aus:
+        #  http://www.marcoprestel.de/stil12.html
+        self.VERBS = [u"gehören", u"liegen", u"beinhalten", u"enthalten", u"befinden", u"geben", u"bewirken", u"bewerkstelligen", u"vergegenwärtigen"]
+
+    def evaluate(self, node):
+        words = node.words()
+        A = Analyzer.instance()
+        corp = A.get(corpus=u"TIGER")
+        sents_count = len(node.sents(tokenizer=corp.sent_tokenizer()))
+        tagger = corp.tagger(True)
+        tagged_words = tagger.tag(words)
+        count = 0
+        if len(tagged_words) > 0:
+            for w in tagged_words:
+                if w[1] and w[1].startswith(u"V"):
+                    lemm = lemma(w[0])
+                    if lemm in self.VERBS:
+                        count += 1
+            return float(count) / sents_count
+        return 0.0
+Analyzer.register(DeadVerbsMetric())
 
 class FillerMetric(Metric):
     """Number of fillers relative to total number of words of a given Node.
